@@ -1,7 +1,7 @@
 // drumkv1_sample.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -41,6 +41,15 @@ drumkv1_sample::drumkv1_sample ( float srate )
 }
 
 
+// copy-ctor.
+drumkv1_sample::drumkv1_sample ( const drumkv1_sample& sample )
+	: drumkv1_sample(sample.m_srate)
+{
+	m_offset  = sample.m_offset;
+	m_reverse = sample.m_reverse;
+}
+
+
 // dtor.
 drumkv1_sample::~drumkv1_sample (void)
 {
